@@ -1,9 +1,11 @@
+#!/bin/false
+
 #
 # BZ::Client::API - Abstract base class for the clients of the Bugzilla API.
 #
 
 use strict;
-use warnings "all";
+use warnings 'all';
 
 package BZ::Client::API;
 
@@ -34,4 +36,4 @@ are subclassing this one, in order to inherit common functionality.
 =head1 SEE ALSO
 
   L<BZ::Client>
- 
\ No newline at end of file
+
