@@ -1,23 +1,25 @@
 #
 # BZ::Client::XMLRPC::Parser - A parser for an XML-RPC response.
 #
+package BZ::Client::XMLRPC::Parser;
+
+use BZ::Client::XMLRPC::Response();
+
 use strict;
 use warnings "all";
 
-package BZ::Client::XMLRPC::Parser;
-$BZ::Client::XMLRPC::Parser::VERSION = '1.062_2';
-use BZ::Client::XMLRPC::Response();
-
 use XML::Parser();
 
-sub new {
+our $VERSION = "1.0";
+
+sub new($@) {
     my $class = shift;
     my $self = { @_ };
     bless($self, ref($class) || $class);
     return $self;
 }
 
-sub parse {
+sub parse($$) {
     my($self, $content) = @_;
     $self->{'stack'} = [];
     my $handler = BZ::Client::XMLRPC::Response->new();
@@ -52,7 +54,7 @@ sub parse {
     return $self->{"result"};
 }
 
-sub register {
+sub register($$$) {
     my($self, $parent, $handler, $code) = @_;
     my $current = [$parent, $handler, $code];
     if ($parent->can("dec_level")) {
@@ -63,7 +65,7 @@ sub register {
     $handler->init($self);
 }
 
-sub remove {
+sub remove($$) {
     my($self, $handler) = @_;
     my $stack = $self->{'stack'};
     my $top = pop(@$stack);
@@ -74,58 +76,21 @@ sub remove {
     &$code($parent, $h);
 }
 
-sub error {
+sub error($$) {
     my($self, $message) = @_;
     require BZ::Client::Exception;
     BZ::Client::Exception->throw("message" => $message);
 }
 
-sub result {
-    my $self = shift;
+sub result($) {
+    my($self) = shift;
     my $res = $self->{"result"};
     return $res;
 }
 
-sub exception {
-    my $self = shift;
+sub exception($) {
+    my($self) = shift;
     return $self->{"exception"};
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-BZ::Client::XMLRPC::Parser
-
-=head1 VERSION
-
-version 1.062_2
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Dean Hamstead <dean@bytefoundry.com.au>
-
-=item *
-
-Jochen Wiedmann <jochen.wiedmann@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Dean Hamstad.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
